==> magpie-data-0.5.16-sources.jar: io/openraven/magpie/data/aws/kms/KmsKey.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.kms;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.kms.model.KeyListEntry;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = KmsKey.TABLE_NAME)
public class KmsKey extends AWSResource {

  protected static final String TABLE_NAME = "awskmskey";
  public static final String RESOURCE_TYPE = "AWS::Kms::Key";

  public KmsKey() {
    this.resourceType = RESOURCE_TYPE;

  }

  public KmsKey(String account, String regionId, KeyListEntry key) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = key.keyArn();
    this.resourceId = key.keyId();
    this.resourceName = key.toString();
    this.configuration = PayloadUtils.update(key);
    this.resourceType = RESOURCE_TYPE;
  }

}

==> magpie-data-0.11.2-sources.jar: io/openraven/magpie/data/aws/kms/KmsKey.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.kms;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.kms.model.KeyListEntry;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = KmsKey.TABLE_NAME)
public class KmsKey extends AWSResource {

  protected static final String TABLE_NAME = "awskmskey";
  public static final String RESOURCE_TYPE = "AWS::Kms::Key";

  public KmsKey() {
    this.resourceType = RESOURCE_TYPE;

  }

  public KmsKey(String account, String regionId, KeyListEntry key) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = key.keyArn();
    this.resourceId = key.keyId();
    this.resourceName = key.toString();
    this.configuration = PayloadUtils.update(key);
    this.resourceType = RESOURCE_TYPE;
  }

}
